annotations library

Classes

IgnoreMap
Annotation to ignore a field during mapping.
Mapper
Use this annotation to generate mapping extension methods for data classes.
MapTo
Annotation to map a source field to a target field with a different name.