constructor property
The name of the target class constructor to use. If null, the default (unnamed) constructor is used.
Implementation
final String? constructor;
The name of the target class constructor to use. If null, the default (unnamed) constructor is used.
final String? constructor;