Mapper class
Annotation to mark a class as a Mapper.
Use this annotation to generate mapping extension methods for data classes.
Usage:
@Mapper(UserModel)
class User { ... }
This will generate a toUserModel() extension method on the User class.
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited