Mapper constructor
Creates a Mapper annotation.
target is the Type of the class you want to map TO.
reverse if true, generates a reverse mapping method (Target -> Source).
constructor the name of the target constructor to use.
Implementation
const Mapper(this.target, {this.reverse = true, this.constructor});