Mapper constructor

const Mapper(
  1. Type target, {
  2. bool reverse = true,
})

Creates a Mapper annotation.

target is the Type of the class you want to map TO. reverse if true, generates a reverse mapping method (Target -> Source).

Implementation

const Mapper(this.target, {this.reverse = true});